@@ -26,11 +26,12 @@ const (
 	// PermissionDeleteNetworking is a set of permissions required when the installer destroys networking resources.
 	PermissionDeleteNetworking PermissionGroup = "delete-networking"
 
-	// PermissionCreateSharedNetworking is a set of permissions required when the installer creates resources in a shared-network cluster.
-	PermissionCreateSharedNetworking PermissionGroup = "create-shared-networking"
-
 	// PermissionDeleteSharedNetworking is a set of permissions required when the installer destroys resources from a shared-network cluster.
 	PermissionDeleteSharedNetworking PermissionGroup = "delete-shared-networking"
+
+	// PermissionDeleteSharedInstanceRole is a set of permissions required when the installer destroys resources from a
+	// cluster with user-supplied IAM roles for instances.
+	PermissionDeleteSharedInstanceRole PermissionGroup = "delete-shared-instance-role"
 )
 
 var permissions = map[PermissionGroup][]string{
@@ -222,13 +223,13 @@ var permissions = map[PermissionGroup][]string{
 		"ec2:ReplaceRouteTableAssociation",
 	},
 	// Permissions required for deleting a cluster with shared network resources
-	PermissionCreateSharedNetworking: {
-		"tag:TagResources",
-	},
-	// Permissions required for deleting a cluster with shared network resources
 	PermissionDeleteSharedNetworking: {
 		"tag:UnTagResources",
 	},
+	// Permissions required for deleting a cluster with shared instance roles
+	PermissionDeleteSharedInstanceRole: {
+		"iam:UntagRole",
+	},
 }
 
 // ValidateCreds will try to create an AWS session, and also verify that the current credentials
